@@ -7,7 +7,7 @@ import random
 from glob import glob
 from .extracteur import ExtracteurDeJus
 from play_sounds import play_file
-from pathlib import Path
+from pathlib import Path, PurePosixPath
 import time
 directory = os.path.dirname(os.path.abspath(__file__))
 
@@ -20,11 +20,9 @@ class nectar(ExtracteurDeJus):
         self.failure_files = glob(os.path.join(directory, 'Sounds', 'Kaamelott', 'Echec', '*.wav'))
 
     def success(self):
-        time.sleep(0.5)
         p = Path(random.choice(self.success_files), encoding=None)
-        play_file(p)
+        play_file(Path(str(PurePosixPath(p))))
 
     def failure(self):
-        time.sleep(0.5)
         p = Path(random.choice(self.failure_files), encoding=None)
-        play_file(p)
+        play_file(Path(str(PurePosixPath(p))))
